import * as vue from 'vue';
import { PropType } from 'vue';
import * as _chakra_ui_styled_system from '@chakra-ui/styled-system';
import { HTMLChakraProps, ThemingProps, SystemProps } from '@chakra-ui/vue-system';

interface CCheckboxControlProps {
    isIndeterminate?: boolean;
    /**
     * If `true`, the checkbox will be disabled
     */
    isDisabled?: boolean;
    /**
     * If `true` and `disabled` is passed, the checkbox will
     * remain tabbable but not interactive
     */
    isFocusable?: boolean;
    /**
     * If `true`, the checkbox will be readonly
     */
    isReadonly?: boolean;
    /**
     * If `true`, the checkbox is marked as invalid.
     */
    isInvalid?: boolean;
    /**
     * If `true`, the checkbox input is marked as required,
     */
    isRequired?: boolean;
    /**
     * The name of the input field in a checkbox
     * (Useful for form submission).
     */
    name?: string;
    /**
     * The value to be used in the checkbox input.
     * This is the value that will be returned on form submission.
     */
    value?: string | number;
    /**
     * Defines the string that labels the checkbox element.
     */
    "aria-label"?: string;
    "aria-labelledby"?: string;
    "aria-invalid"?: boolean;
    "aria-describedby"?: string;
    tabIndex?: number | string;
}
interface CCheckboxProps extends HTMLChakraProps<"input">, ThemingProps<"Checkbox">, CCheckboxControlProps {
    /**
     * The spacing between the checkbox and its label text
     * @default 0.5rem
     * @type SystemProps["marginLeft"]
     */
    spacing?: SystemProps["marginLeft"];
    /**
     * The color of the checkbox icon when checked or indeterminate
     */
    iconColor?: string;
    /**
     * The size of the checkbox icon when checked or indeterminate
     */
    iconSize?: string | number;
    /**
     * The checked icon to use
     */
    icon?: any;
    /**
     * Additional props to be forwarded to the `input` element
     */
    inputProps?: HTMLChakraProps<"input">;
}
declare const CCheckbox: vue.DefineComponent<{
    colorScheme: PropType<(string & {}) | "blue" | "cyan" | "gray" | "green" | "orange" | "pink" | "purple" | "red" | "teal" | "yellow" | "whiteAlpha" | "blackAlpha" | "linkedin" | "facebook" | "messenger" | "whatsapp" | "twitter" | "telegram" | undefined>;
    variant: PropType<any>;
    size: PropType<any>;
    styleConfig: PropType<Record<string, any> | undefined>;
    modelValue: {
        type: PropType<boolean>;
        default: boolean;
    };
    value: PropType<string | number | undefined>;
    id: PropType<string>;
    isIndeterminate: PropType<boolean | undefined>;
    isFocusable: PropType<boolean | undefined>;
    isRequired: PropType<boolean | undefined>;
    isInvalid: PropType<boolean | undefined>;
    isDisabled: PropType<boolean | undefined>;
    isReadonly: PropType<boolean | undefined>;
    defaultChecked: PropType<boolean>;
    name: PropType<string | undefined>;
    "aria-label": PropType<string | undefined>;
    "aria-labelledby": PropType<string | undefined>;
    "aria-invalid": PropType<boolean | undefined>;
    "aria-describedby": PropType<string | undefined>;
    spacing: {
        type: PropType<_chakra_ui_styled_system.ResponsiveValue<number | (string & {}) | "px" | "initial" | "-moz-initial" | "inherit" | "revert" | "revert-layer" | "unset" | "auto" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "-1" | "-2" | "-3" | "-4" | "-5" | "-6" | "-7" | "-8" | "-9" | "-10" | "-12" | "-14" | "-16" | "-20" | "-24" | "-28" | "-32" | "-36" | "-40" | "-44" | "-48" | "-52" | "-56" | "-60" | "-64" | "-72" | "-80" | "-96" | "-px" | "-0.5" | "-1.5" | "-2.5" | "-3.5"> | undefined>;
        default: string;
    };
    iconColor: PropType<string | undefined>;
    iconSize: PropType<string | number | undefined>;
    icon: PropType<any>;
    inputProps: PropType<HTMLChakraProps<"input"> | undefined>;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, ("change" | "update:modelValue")[], "change" | "update:modelValue", vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{
    colorScheme: PropType<(string & {}) | "blue" | "cyan" | "gray" | "green" | "orange" | "pink" | "purple" | "red" | "teal" | "yellow" | "whiteAlpha" | "blackAlpha" | "linkedin" | "facebook" | "messenger" | "whatsapp" | "twitter" | "telegram" | undefined>;
    variant: PropType<any>;
    size: PropType<any>;
    styleConfig: PropType<Record<string, any> | undefined>;
    modelValue: {
        type: PropType<boolean>;
        default: boolean;
    };
    value: PropType<string | number | undefined>;
    id: PropType<string>;
    isIndeterminate: PropType<boolean | undefined>;
    isFocusable: PropType<boolean | undefined>;
    isRequired: PropType<boolean | undefined>;
    isInvalid: PropType<boolean | undefined>;
    isDisabled: PropType<boolean | undefined>;
    isReadonly: PropType<boolean | undefined>;
    defaultChecked: PropType<boolean>;
    name: PropType<string | undefined>;
    "aria-label": PropType<string | undefined>;
    "aria-labelledby": PropType<string | undefined>;
    "aria-invalid": PropType<boolean | undefined>;
    "aria-describedby": PropType<string | undefined>;
    spacing: {
        type: PropType<_chakra_ui_styled_system.ResponsiveValue<number | (string & {}) | "px" | "initial" | "-moz-initial" | "inherit" | "revert" | "revert-layer" | "unset" | "auto" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "-1" | "-2" | "-3" | "-4" | "-5" | "-6" | "-7" | "-8" | "-9" | "-10" | "-12" | "-14" | "-16" | "-20" | "-24" | "-28" | "-32" | "-36" | "-40" | "-44" | "-48" | "-52" | "-56" | "-60" | "-64" | "-72" | "-80" | "-96" | "-px" | "-0.5" | "-1.5" | "-2.5" | "-3.5"> | undefined>;
        default: string;
    };
    iconColor: PropType<string | undefined>;
    iconSize: PropType<string | number | undefined>;
    icon: PropType<any>;
    inputProps: PropType<HTMLChakraProps<"input"> | undefined>;
}>> & {
    onChange?: ((...args: any[]) => any) | undefined;
    "onUpdate:modelValue"?: ((...args: any[]) => any) | undefined;
}, {
    modelValue: boolean;
    spacing: _chakra_ui_styled_system.ResponsiveValue<number | (string & {}) | "px" | "initial" | "-moz-initial" | "inherit" | "revert" | "revert-layer" | "unset" | "auto" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "-1" | "-2" | "-3" | "-4" | "-5" | "-6" | "-7" | "-8" | "-9" | "-10" | "-12" | "-14" | "-16" | "-20" | "-24" | "-28" | "-32" | "-36" | "-40" | "-44" | "-48" | "-52" | "-56" | "-60" | "-64" | "-72" | "-80" | "-96" | "-px" | "-0.5" | "-1.5" | "-2.5" | "-3.5"> | undefined;
}>;

export { CCheckbox, CCheckboxControlProps, CCheckboxProps };
